#ifndef NT2_INCLUDE_FUNCTIONS_COPYSIGN_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_COPYSIGN_HPP_INCLUDED

#include <nt2/ieee/include/functions/copysign.hpp>

#endif
